package com.zhilian.common.resolver.domain;

import lombok.*;
import org.springframework.format.annotation.DateTimeFormat;

import java.math.BigDecimal;
import java.util.Date;

/**
  * @ClassName ResolverReportData
  * @Description 解析报文数据
  * @Author Can.J
  * @Date  2024/4/1 11:49
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@Setter
@Getter
public class ResolverReportData {
    /**
     * 主键id
     */
    private Long id;

    /**
     * VIN 车辆编码
     */
    private String vin;

    /**
     *  报文创建时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /**
     *  经度
     */
    private String longitude;

    /**
     * 维度
     */
    private String latitude;

    /**
     *  速度
     */
    private String speed;

    /**
     * 里程
     */
    private BigDecimal mileage;

    /**
     * 总电压
     */
    private String voltage;

    /**
     *  总电流
     */
    private String current;

    /**
     *  绝缘电阻
     */
    private String resistance;

    /**
     *  档位 P:停车 D：运行
     */
    private String gear;

    /**
     * 加速踏板行驶值
     */
    private String accelerationPedal;

    /**
     *  制动踏板行驶值
     */
    private String brakePedal;

    /**
     *  燃料消耗率
     */
    private String fuelConsumptionRate;

    /**
     *  电机控制器温度
     */
    private String motorControllerTemperature;

    /**
     * 电机转速
     */
    private String motorSpeed;

    /**
     *  电机转矩
     */
    private String motorTorque;

    /**
     *  电机温度
     */
    private String motorTemperature;

    /**
     * 电机电压
     */
    private String motorVoltage;

    /**
     *  电机电流
     */
    private String motorCurrent;

    /**
     * 动力电池剩余电量SOC
     */
    private BigDecimal remainingBattery;

    /**
     * 当前状态允许的最大反馈功率
     */
    private String maximumFeedbackPower;

    /**
     *  当前状态允许的最大放电功率
     */
    private String maximumDischargePower;

    /**
     * BMS自检计数器
     */
    private String selfCheckCounter;

    /**
     * 动力电池充放电电流
     */
    private String totalBatteryCurrent;

    /**
     * 动力电池负载端电压V3
     */
    private String totalBatteryVoltage;

    /**
     *  单次最大电压
     */
    private String singleBatteryMaxVoltage;

    /**
     * 单体电池最低电压
     */
    private String singleBatteryMinVoltage;

    /**
     * 单体电池最高温度
     */
    private String singleBatteryMaxTemperature;

    /**
     *  单体电池最低温度
     */
    private String singleBatteryMinTemperature;

    /**
     * 动力电池可用容量
     */
    private String availableBatteryCapacity;

    /**
     * 车辆状态 1：正常 0：故障
     */
    private int vehicleStatus;

    /**
     * 充电状态 1：正常 0：故障
     */
    private int chargingStatus;

    /**
     * 运行状态 1：正常 0：故障
     */
    private int operatingStatus;

    /**
     * SOC 状态 1：正常 0：故障
     */
    private int socStatus;

    /**
     *  可充电储能装置工作状态 1：正常 0：故障
     */
    private int chargingEnergyStorageStatus;

    /**
     *  驱动电机状态 1：正常 0：故障
     */
    private int driveMotorStatus;

    /**
     * 定位是否有效 1：有效 0：无效
     */
    private int positionStatus;

    /**
     * EAS(汽车防盗系统)状态 1：正常 0：故障
     */
    private int easStatus;

    /**
     * PTC(电动加热器)状态 1：正常 0：故障
     */
    private int ptcStatus;

    /**
     * EPS(电动助力系统)状态 1：正常 0：故障
     */
    private int epsStatus;

    /**
     * ABS(防抱死)状态 1：正常 0：故障
     */
    private int absStatus;

    /**
     *  MCU(电机/逆变器)状态 1：正常 0：故障
     */
    private int mcuStatus;

    /**
     *  动力电池加热状态 1：正常 0：故障
     */
    private int heatingStatus;

    /**
     * 动力电池当前状态 1：正常 0：故障
     */
    private int batteryStatus;

    /**
     *  动力电池保温状态 1：正常 0：故障
     */
    private int batteryInsulationStatus;

    /**
     *  DCDC(电力交换系统) 状态 1：正常 0：故障
     */
    private int dcdcStatus;

    /**
     * CHG(充电机)状态 1：正常 0：故障
     */
    private int chgStatus;

}

