package com.zhilian.business.controller;

import com.zhilian.business.domain.Break;
import com.zhilian.business.domain.BreakVo;
import com.zhilian.business.service.BreakService;
import com.zhilian.common.core.domain.Result;
import com.zhilian.common.core.web.page.PageResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * @ClassName BreakController
 * @Description  故障业务实现
 * @Author YuanYongH
 * @Date 2024/4/4 9:40
 */
@RestController
public class BreakController {

    @Autowired
    private BreakService breakService;

    /**
     * @Description // 故障列表
     * @Date 2024/4/4
     * @param breakVo
     * @return com.zhilian.common.core.domain.Result<com.zhilian.common.core.web.page.PageResult<com.zhilian.business.domain.Break>>
    **/
    @PostMapping("breakList")
    public Result<PageResult<Break>> breakList(@RequestBody BreakVo breakVo) {
        PageResult<Break> pageResult = breakService.breakList(breakVo);
        return Result.success(pageResult);
    }

    /**
     * @Description // 故障添加
     * @Date 2024/4/4
     * @param break1
     * @return com.zhilian.common.core.domain.Result
    **/
    @PostMapping("breakAdd")
    public Result breakAdd(@RequestBody Break break1) {
        int i = breakService.breakAdd(break1);
        Result<Integer> success = Result.success(i);
        return success;
    }

    /**
     * @Description // 故障修改
     * @Date 2024/4/4
     * @param break1
     * @return com.zhilian.common.core.domain.Result
    **/
    @PostMapping("breakUpd")
    public Result breadUpd(@RequestBody Break break1) {
        int i = breakService.breakUpd(break1);
        Result<Integer> success = Result.success(i);
        return success;
    }

    /**
     * @Description // 故障删除
     * @Date 2024/4/4
     * @param breakId
     * @return com.zhilian.common.core.domain.Result
    **/
    @PostMapping("breakDel/{breakId}")
    public Result delFirm(@PathVariable Integer breakId){
        int i = breakService.breakDel(breakId);
        Result<Integer> success = Result.success(i);
        return success;
    }
}


























