package com.zhilian.business.controller;

import com.zhilian.business.domain.Fence;
import com.zhilian.common.core.domain.Result;
import com.zhilian.common.core.web.controller.BaseController;
import com.zhilian.business.service.FenceService;
import com.zhilian.common.core.web.page.TableDataInfo;
import com.zhilian.common.security.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;
import java.util.List;

/**
  * @ClassName FenceController
  * @Description 电子围栏控制层
  * @Author ZeJinG.Su
  * @Date  14:37 2024/3/29
 */
@RestController
@RequestMapping("fence")
public class FenceController extends BaseController {
    @Autowired
    private FenceService fenceService;

    /**
     * 电子围栏列表
     * @param fence
     * @return
     */
    @PostMapping("/list")
    public Result<TableDataInfo<Fence>> fenceList(@RequestBody Fence fence) {
        startPage();
        List<Fence> result = fenceService.fenceList(fence);
        return getDataTable(result);
    }


    /**
     * 添加所有围栏信息进入redis
     */
    public void fenceRedisData() {
        fenceService.fenceRedisData();
    }

    /**
     * 新增围栏
     * @param fence
     * @return
     */
    @PostMapping("/fenceAdd")
    public Result fenceAdd(@RequestBody Fence fence) {
        fence.setUpdateBy(SecurityUtils.getUsername());
        fence.setUpdateTime(new Date());
        return toAjax(fenceService.saveFence(fence));
    }


    /**
     * 修改围栏信息
     * @param fence
     * @return
     */
    @PostMapping("/fenceUpdate")
    public Result fenceUpdate(@RequestBody Fence fence) {
        fence.setUpdateBy(SecurityUtils.getUsername());
        fence.setUpdateTime(new Date());
        return toAjax(fenceService.updateById(fence));
    }

    /**
     * 修改电子围栏地图
     * @param fence
     * @return
     */
    @PostMapping("/fenceUpdateMap")
    public Result fenceUpdateMap(@RequestBody Fence fence) {
        fence.setUpdateBy(SecurityUtils.getUsername());
        fence.setUpdateTime(new Date());
        return toAjax(fenceService.updateByMap(fence));
    }

    /**
     * 删除围栏
     * @param
     * @return
     */
    @PostMapping("/fenceDelete/{fenceId}")
    public Result fenceDelete(@PathVariable Long fenceId) {
        return toAjax(fenceService.removeByFence(fenceId));
    }


}
