package com.zhilian.business.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.zhilian.business.domain.Vehicle;
import com.zhilian.business.domain.VehicleFence;
import com.zhilian.business.domain.middle.VehicleMarkers;
import com.zhilian.business.service.MarkersService;
import com.zhilian.business.service.VehicleMarkersService;
import com.zhilian.business.service.VehicleService;
import com.zhilian.business.service.VehicleTypeService;
import com.zhilian.common.core.domain.Result;
import com.zhilian.common.core.web.controller.BaseController;
import com.zhilian.common.core.web.page.TableDataInfo;
import com.zhilian.common.security.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;
import java.util.List;

@RestController
@RequestMapping("/vehicle")
public class VehicleController extends BaseController {
    @Autowired
    private VehicleService vehicleService;

    @Autowired
    private VehicleMarkersService vehicleMarkersService;

    @Autowired
    private VehicleTypeService vehicleTypeService;


    @Autowired
    private MarkersService markersService;


    /**
     * 查询车辆列表
     * @param vehicle
     * @return
     */
    @PostMapping("/list")
    public Result<TableDataInfo<Vehicle>> list(@RequestBody Vehicle vehicle) {
        startPage();
        List<Vehicle> list = vehicleService.selectVehicleList(vehicle);
        return getDataTable(list);
    }

    @GetMapping("/vehicleSelectAllData")
    public List<VehicleFence> vehicleSelectAllData(){
        List<VehicleFence> selectSelectAllData = vehicleService.selectSelectAllData();
        return selectSelectAllData;
    }

    /**
     * 新增车辆
     * @param vehicle
     * @return
     */
    @PostMapping("/vehicleInsert")
    public Result vehicleInsert(@RequestBody Vehicle vehicle){
        vehicle.setCreateBy(SecurityUtils.getUsername());
        vehicle.setCreateTime(new Date());
        return toAjax(vehicleService.save(vehicle));
    }

    /**
     * 修改车辆
     * @param vehicle
     * @return
     */
    @PostMapping("/vehicleUpdate")
    public Result vehicleUpdate(@RequestBody Vehicle vehicle){
        vehicle.setUpdateBy(SecurityUtils.getUsername());
        vehicle.setUpdateTime(new Date());

        //删除中间表全部关联数据
        vehicleMarkersService.removeAllVehicle(vehicle);

        //修改原表数据
        boolean update =vehicleService.updateById(vehicle);

        //重新添加中间表数据
        vehicleMarkersService.insert(vehicle);

        //判断添加完成后的标识与围栏是否绑定事件 如果没有绑定全部删除围栏事件 然后进行给予绑定
        vehicleService.selectRedisData(vehicle);
        return toAjax(update);
    }

    /**
     * 根据车辆ID查询车辆与围栏中间表
     * @param vehicleId
     * @return
     */
    @PostMapping("/getVehicleMarkers/{vehicleId}")
    public List<VehicleMarkers> getVehicleMarkers(@PathVariable Long vehicleId){
        LambdaQueryWrapper<VehicleMarkers> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(VehicleMarkers::getVehicleId, vehicleId);
        return vehicleMarkersService.list(queryWrapper);
    }
    /**
     * 删除车辆
     * @param vehicleId
     * @return
     */
    @PostMapping("/vehicleDelete/{vehicleId}")
    public Result vehicleDelete(@PathVariable Long vehicleId){
        getVehicleMarkers(vehicleId).forEach(vehicleMarkers -> {
            vehicleMarkersService.removeById(vehicleId);
        });
        return toAjax(vehicleService.removeById(vehicleId));
    }

    /**
     * 车辆绑定围栏
     * @param vehicle
     * @return
     */
    @PostMapping("/vehicleInsertMarkers")
    public Result vehicleInsertMarkers(@RequestBody Vehicle vehicle){
        boolean insert = vehicleMarkersService.insert(vehicle);
        return toAjax(insert);
    }

    /**
     * 根据VIN查询车辆信息
     * @param vehicleVIN
     * @return
     */
    @PostMapping("/getMarkersByVIN/{vehicleVIN}")
    public Result<Vehicle> getVehicleByVIN(@PathVariable("vehicleVIN") String vehicleVIN) {
         Vehicle vehicle = vehicleService.getVehicleByVIN(vehicleVIN);
//         vehicleMarkersService.getById(vehicle.getVehicleId());
         return Result.success(vehicle);
    }

    /**
     * 根据车辆VIN修改车辆状态
     * @param vehicle
     * @return
     */
    @PostMapping("/updateState")
    public Result updateState(@RequestBody Vehicle vehicle) {
        return toAjax(vehicleService.updateState(vehicle));
    }
}
