//package com.zhilian.online.config;
//
//import com.fasterxml.jackson.databind.annotation.JsonSerialize;
//import com.zhilian.common.core.domain.Result;
//import com.zhilian.common.core.utils.SpringUtils;
//import com.zhilian.common.core.utils.StringUtils;
//import com.zhilian.online.service.OnlineGatherService;
//import com.zhilian.online.service.OnlineLoadCenterService;
//import org.apache.kafka.clients.producer.ProducerConfig;
//import org.junit.jupiter.api.Test;
//import org.springframework.beans.factory.annotation.Value;
//import org.springframework.context.annotation.Bean;
//import org.springframework.context.annotation.Configuration;
//import org.springframework.kafka.core.DefaultKafkaProducerFactory;
//import org.springframework.kafka.core.KafkaTemplate;
//import org.springframework.kafka.core.ProducerFactory;
//import org.springframework.kafka.transaction.KafkaTransactionManager;
//
//import java.util.HashMap;
//import java.util.Map;
//import java.util.Objects;
//
///**
// * @BelongsProject: smart-cloud-server
// * @BelongsPackage: com.zhilian.online.config
// * @Author: LiYuan
// * @CreateTime: 2024-04-02  19:36
// * @Description: kafka生产者配置
// * @Version: 1.0
// */
//@Configuration
//public class KafkaProviderConfig {
//
//    /**
//     * kafka服务器地址
//     */
//    @Value("${spring.kafka.producer.bootstrap-servers}")
//    private String bootstrapServers;
//
//    /**
//     * kafka开启事务
//     */
//    @Value("${spring.kafka.producer.transaction-id-prefix}")
//    private String transactionIdPrefix;
//
//    /**
//     * 手动提交确认信息
//     */
//    @Value("${spring.kafka.producer.acks}")
//    private String acks;
//
//    /**
//     * 发生错误后消息重发次数
//     */
//    @Value("${spring.kafka.producer.retries}")
//    private String retries;
//
//    /**
//     * 当有多个消息需要被发送到同一个分区时，生产者会把它们放在同一个批次里。
//     * 该参数指定了一个批次可以使用的内存大小，按照字节数计算
//     */
//    @Value("${spring.kafka.producer.batch-size}")
//    private String batchSize;
//
//    /**
//     * 生产者内存缓冲区大小
//     */
//    @Value("${spring.kafka.producer.buffer-memory}")
//    private String bufferMemory;
//
//    /**
//     * 生产者最短发送消息时间
//     */
//    @Value("${spring.kafka.producer.linger-ms}")
//    private String lingerMs;
//
//
//    /**
//     * 配置生产者配置对象
//     * @return props
//     */
//    @Bean
//    public Map<String, Object> producerConfigs() {
//        Map<String, Object> props = new HashMap<>();
//        //设置生产者服务器
//        props.put(ProducerConfig.BOOTSTRAP_SERVERS_CONFIG,bootstrapServers);
//        //acks=0 ： 生产者在成功写入消息之前不会等待任何来自服务器的响应。
//        //acks=1 ： 只要集群的首领节点收到消息，生产者就会收到一个来自服务器成功响应。
//        //acks=all ：只有当所有参与复制的节点全部收到消息时，生产者才会收到一个来自服务器的成功响应。
//        //开启事务必须设为all
//        props.put(ProducerConfig.ACKS_CONFIG,acks);
//        //设置发生错误后消息重发次数
//        props.put(ProducerConfig.RETRIES_CONFIG,retries);
//        //当多个消息发送到相同分区时,生产者会将消息打包到一起发送,减少请求交互
//        //批次的大小可以通过batch.size 参数设置.默认是16KB
//        //较小的批次大小有可能降低吞吐量（批次大小为0则完全禁用批处理）。
//        //比如说，kafka里的消息5秒钟Batch才凑满了16KB，才能发送出去。那这些消息的延迟就是5秒钟
//        //实测batchSize这个参数没有用
//        props.put(ProducerConfig.BATCH_SIZE_CONFIG,batchSize);
//        //有的时刻消息比较少,过了很久,比如5min也没有凑够16KB,这样延时就很大,所以需要一个参数. 再设置一个时间,到了这个时间,
//        //即使数据没达到16KB,也将这个批次发送出去
//        props.put(ProducerConfig.LINGER_MS_CONFIG,lingerMs);
//        //设置生产者内存缓冲区大小
//        props.put(ProducerConfig.BUFFER_MEMORY_CONFIG,bufferMemory);
//        //反序列化
//        props.put(ProducerConfig.KEY_SERIALIZER_CLASS_CONFIG, JsonSerialize.class);
//        props.put(ProducerConfig.VALUE_SERIALIZER_CLASS_CONFIG, JsonSerialize.class);
//        return  props;
//    }
//
//    /**
//     * 生产者开启事务配置
//     * @return factory
//     */
//    @Bean
//    public ProducerFactory<Object,Object> producerFactory(){
//        DefaultKafkaProducerFactory<Object,Object> factory = new DefaultKafkaProducerFactory<>(producerConfigs());
//        //开启事务,会导致 LINGER_MS_CONFIG配置失效
//        factory.setTransactionIdPrefix(transactionIdPrefix);
//        return factory;
//    }
//
//    /**
//     * kafka事务管理器
//     * @param producerFactory
//     * @return KafkaTransactionManager
//     */
//    @Bean
//    public KafkaTransactionManager<Object,Object> kafkaTransactionManager(ProducerFactory<Object,Object> producerFactory){
//        return new KafkaTransactionManager<>(producerFactory);
//    }
//
//    /**
//     * 创建Kafka生产者实例
//     * @return KafkaTemplate
//     */
//    @Bean
//    public KafkaTemplate<Object,Object> kafkaTemplate(){
//        return new KafkaTemplate<>(producerFactory());
//    }
//
//
//
//}
