package com.zhilian.online.controller;

import com.alibaba.fastjson.JSON;
import com.zhilian.common.core.domain.Result;
import com.zhilian.common.core.utils.ip.IpUtils;
import com.zhilian.common.core.web.controller.BaseController;

import com.zhilian.online.domain.Gather;
import com.zhilian.online.service.OnlineLoadCenterService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * @version:
 * @Author: LiYuan
 * @description: 负载中心Controller
 * @date: 2024/3/29  20:40
 */
@RestController
@RequestMapping("/load/center")
@Slf4j
public class OnlineLoadCenterController extends BaseController {

    /**
     * 请求对象
     */
    @Autowired
    private HttpServletRequest request;

    /**
     * 车辆收集节点服务层
     */
    @Autowired
    private OnlineLoadCenterService onlineLoadCenterService;


    /**
     * @description: 节点申请注解令牌接口, 仅限内网访问
     * @author: LiYuan
     * @param: vehicle
     * @return: Result<OnlineAccount>
     **/
    @GetMapping("/applyForReg")
    public Result<String> applyForReg(Gather gather) {
        log.info("申请注册令牌{}", JSON.toJSONString(gather));
        return onlineLoadCenterService.applyForReg(gather);
    }


    /**
     * @description: 收集节点注册
     * @author: LiYuan
     * @param: Gather
     * @return: Result
     **/
    @PostMapping("/regGather")
    public Result regGather(@Validated @RequestBody Gather gather) {
        String ipAddr = IpUtils.getIpAddr(request);
        gather.setIpAddress(ipAddr);
        log.info("节点{}正在上线", JSON.toJSONString(gather));
        return onlineLoadCenterService.regGather(gather);
    }


    /**
     * 车辆申请上线收集节点
     *
     * @return gather
     * @author: LiYuan
     * @param: vin
     * @return: Result
     */
    @GetMapping("/applyForConnectToGather")
    public Result applyForConnectToGather(@RequestParam("vin") String vin) {
        return Result.success(onlineLoadCenterService.applyForConnectToGather(vin));
    }

    /**
     * @description:车辆下线接口
     * @author: LiYuan
     * @param: vin
     * @return: Result
     **/
    @GetMapping("/applyForDisconnectToGather")
    public Result applyForDisconnectToGather(@RequestParam("vin") String vin) {
        onlineLoadCenterService.applyForDisconnectToGather(vin);
        return Result.success();
    }


}
