package com.zhilian.resolver.service.impl.eventMalfunction;
import com.zhilian.business.domain.BreakLog;
import com.zhilian.business.remote.RemoteBreakService;
import com.zhilian.common.redis.service.RedisService;
import com.zhilian.common.resolver.domain.ResolverReportData;
import com.zhilian.resolver.mapper.UserMapper;
import com.zhilian.resolver.service.ResolverEventService;
import com.zhilian.resolver.service.ResolverReportInfoService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.HashSet;
import java.util.Optional;
import java.util.Set;
import java.util.concurrent.TimeUnit;

/**
 * @ClassName MalfunctionEventServiceImpl
 * @Description 故障事件服务
 * @Author Can.J
 * @Date  2024/4/4 10:00
 */
@Slf4j
@Service("malfunction")
public class MalfunctionEventServiceImpl implements ResolverEventService {
    @Autowired
    private RedisService redisService;

    /**
     *  获取用信息 模拟故障
     */
    @Autowired
    private UserMapper userMapper;

    /**
     *  注入ResolverReportInfoService 业务层
     */
    @Autowired
    private ResolverReportInfoService resolverReportInfoService;

    /**
     *  远程调用 BreakLog服务
     */
    @Autowired
    private RemoteBreakService remoteBreakService;

    @Override
    public void execute(ResolverReportData vehicleData) {
        log.info("故障事件开始执行");
        if(isAnyFieldZero(vehicleData)){
            resolverReportInfoService.saveDataToDatabaseByMalfunction(vehicleData);

            BreakLog breakLog = new BreakLog();
            breakLog.setBreakVin(vehicleData.getVin());

            //     * 车辆状态 1：正常 0：故障
            switch (vehicleData.getVehicleStatus()) {
                case 0:
                    breakLog.setBreakCode("CL001");
                    breakLog.setBreakType("车体故障");
                    breakLog.setBreakState("1");                                break;
                default:
                    break;
            }

            switch (vehicleData.getChargingStatus()) {
                case 0:
                    breakLog.setBreakCode("CD001");
                    breakLog.setBreakType("电池故障");
                    breakLog.setBreakState("1");                                break;
                default:
                    break;
            }

            switch (vehicleData.getOperatingStatus()) {
                case 0:
                    breakLog.setBreakCode("DW001");
                    breakLog.setBreakType("行驶故障");
                    breakLog.setBreakState("1");                                break;
                default:
                    break;
            }

            switch (vehicleData.getSocStatus()) {
                case 0:
                    breakLog.setBreakCode("SOC001");
                    breakLog.setBreakType("电池故障");
                    breakLog.setBreakState("1");                                break;
                default:
                    break;
            }

            switch (vehicleData.getChargingEnergyStorageStatus()) {
                case 0:
                    breakLog.setBreakCode("CDC001");
                    breakLog.setBreakType("电池故障");
                    breakLog.setBreakState("1");                                break;
                default:
                    break;
            }

            switch (vehicleData.getDriveMotorStatus()) {
                case 0:
                    breakLog.setBreakCode("DJ001");
                    breakLog.setBreakType("电机故障");
                    breakLog.setBreakState("1");                                break;
                default:
                    break;
            }

            switch (vehicleData.getPositionStatus()) {
                case 0:
                    breakLog.setBreakCode("SOC001");
                    breakLog.setBreakType("定位故障");
                    breakLog.setBreakState("1");                                break;
                default:
                    break;
            }

            switch (vehicleData.getEasStatus()) {
                case 0:
                    breakLog.setBreakCode("EAS001");
                    breakLog.setBreakType("EAS故障");
                    breakLog.setBreakState("1");                                break;
                default:
                    break;
            }

            switch (vehicleData.getPtcStatus()) {
                case 0:
                    breakLog.setBreakCode("PTC001");
                    breakLog.setBreakType("加热故障");
                    breakLog.setBreakState("1");                                break;
                default:
                    break;
            }

            switch (vehicleData.getEpsStatus()) {
                case 0:
                    breakLog.setBreakCode("EPS001");
                    breakLog.setBreakType("电动助力故障");
                    breakLog.setBreakState("1");                                break;
                default:
                    break;
            }

            switch (vehicleData.getAbsStatus()) {
                case 0:
                    breakLog.setBreakCode("ABS001");
                    breakLog.setBreakType("ABS故障");
                    breakLog.setBreakState("1");
                    break;
                default:
                    break;
            }

            switch (vehicleData.getMcuStatus()) {
                case 0:
                    breakLog.setBreakCode("MCU001");
                    breakLog.setBreakType("MCU故障");
                    breakLog.setBreakState("1");
                    break;
                default:
                    break;
            }

            switch (vehicleData.getHeatingStatus()) {
                case 0:
                    breakLog.setBreakCode("DC002");
                    breakLog.setBreakType("电池故障");
                    breakLog.setBreakState("1");
                    break;
                default:
                    break;
            }

            switch (vehicleData.getBatteryStatus()) {
                case 0:
                    breakLog.setBreakCode("DC003");
                    breakLog.setBreakType("电池故障");
                    breakLog.setBreakState("1");
                    break;
                default:
                    break;
            }

            switch (vehicleData.getBatteryInsulationStatus()) {
                case 0:
                    breakLog.setBreakCode("DC004");
                    breakLog.setBreakType("电池故障");
                    breakLog.setBreakState("1");
                    break;
                default:
                    break;
            }

            switch (vehicleData.getDcdcStatus()) {
                case 0:
                    breakLog.setBreakCode("DCDC005");
                    breakLog.setBreakType("电力故障");
                    breakLog.setBreakState("1");
                    break;
                default:
                    break;
            }

            switch (vehicleData.getChgStatus()) {
                case 0:
                    breakLog.setBreakCode("CDJ005");
                    breakLog.setBreakType("电力故障");
                    breakLog.setBreakState("1");
                    break;
                default:
                    break;
            }

            HashSet<BreakLog> breakHash = new HashSet<>();
            breakHash.add(breakLog);


            redisService.setCacheSet("breakdown:gz:："+vehicleData.getVin(),breakHash);

            Set<BreakLog> breakLogsFromRedis = redisService.getCacheSet("breakdown:gz:：" + vehicleData.getVin());
            if(breakLogsFromRedis !=null && !breakLogsFromRedis.isEmpty()){
                // 检查第一条故障记录是否已存在于数据库中
                BreakLog firstBreakLog = breakLogsFromRedis.iterator().next();
                if (!isInDatabase(firstBreakLog)) {
                    remoteBreakService.logAdd(firstBreakLog);
                }
            }else {
                log.info("没有找到对应VIN的故障记录在Redis中，无需同步到数据库");
            }

            long expireTime = 30;
            redisService.expire("breakdown:gz:"+vehicleData.getVin(), expireTime, TimeUnit.MINUTES);

        }


        log.info("故障事件结束");

    }
    private boolean isAnyFieldZero(ResolverReportData resolverReportData) {
        return resolverReportData.getChargingStatus() == 0 ||
                resolverReportData.getOperatingStatus() == 0 ||
                resolverReportData.getSocStatus() == 0 ||
                resolverReportData.getVehicleStatus() == 0 ||
                resolverReportData.getChargingEnergyStorageStatus() == 0 ||
                resolverReportData.getDriveMotorStatus() == 0 ||
                resolverReportData.getPositionStatus() == 0 ||
                resolverReportData.getEasStatus() == 0 ||
                resolverReportData.getPtcStatus() == 0 ||
                resolverReportData.getEpsStatus() == 0 ||
                resolverReportData.getAbsStatus() == 0 ||
                resolverReportData.getMcuStatus() == 0 ||
                resolverReportData.getHeatingStatus() == 0 ||
                resolverReportData.getBatteryStatus() == 0 ||
                resolverReportData.getBatteryInsulationStatus() == 0 ||
                resolverReportData.getDcdcStatus() == 0 ||
                resolverReportData.getChgStatus() == 0;

    }
    @Override
    public String getEventName() {
        return "malfunction";
    }

    private boolean isInDatabase(BreakLog breakLog) {
        // 查询数据库，判断是否已存在相同的故障记录
        // 故障记录的唯一标识是breakCode和breakVin
        ResponseEntity<Boolean> existingBreakLog = remoteBreakService.checkIfBreakLogExists(breakLog.getBreakCode(), breakLog.getBreakVin());
        return existingBreakLog != null && existingBreakLog.getBody();

    }
}
